OC.L10N.register(
    "files_rightclick",
    {
    "Unselect all" : "Deseleicionar too"
},
"nplurals=2; plural=(n != 1);");
